@@ -3,11 +3,11 @@ import platform
 
 VERSION_MAJOR = 0
 VERSION_MINOR = 9
-VERSION_RELEASE = 0
-VERSION_NUMBER = "0.9.0"
-VERSION = "0.9.0"
+VERSION_RELEASE = 14
+VERSION_NUMBER = "0.9.14"
+VERSION = "0.9.14"
 
-REVISION = 13850
+REVISION = 14491
 
 HANDLE_INVALID = 0
 
@@ -450,11 +450,17 @@ PID_HP3 = 18
 PID_TP450 = 19
 PID_HS4D = 20
 PID_HS5 = 22
+PID_HS6 = 24
 PID_HS6D = 25
 PID_ATS610004D = 31
 PID_ATS605004D = 32
 PID_WS6 = 34
 PID_WS5 = 35
+PID_WS6D = 36
+PID_ATS610004DW = 37
+PID_ATS605004DW = 38
+PID_WS4D = 39
+PID_ATS5004DW = 40
 
 EVENTID_INVALID = 0
 EVENTID_OBJ_REMOVED = 1
